@@ -81,12 +81,14 @@ class App final : public QObject
   void saveMainWindowGeometry();
 
  private:
-  bool toSysTray();
+  void initSysTrayWindowState();
   void setupCmdParser(QCommandLineParser &parser, int minHelperTimeout,
                       int helperTimeout) const;
   void buildUI(QQmlApplicationEngine &qmlEngine);
   void setupMainWindowGeometry();
   void restoreMainWindowGeometry();
+  bool handleToggleManualProfileCmd();
+  bool handleWindowVisibilityCmds();
 
   AppInfo appInfo_;
   SingleInstance singleInstance_;
