@@ -39,9 +39,9 @@
 #include <QStandardPaths>
 #include <algorithm>
 #include <cctype>
-#include <easylogging++.h>
 #include <exception>
-#include <fmt/format.h>
+#include <format>
+#include <spdlog/spdlog.h>
 #include <system_error>
 #include <utility>
 
@@ -108,8 +108,8 @@ std::unique_ptr<App> AppFactory::build() const
                                  std::move(uiFactory));
   }
   catch (std::exception const &e) {
-    LOG(WARNING) << "Cannot create main application";
-    LOG(WARNING) << e.what();
+    SPDLOG_WARN("Cannot create main application");
+    SPDLOG_WARN(e.what());
   }
 
   return nullptr;
@@ -139,44 +139,44 @@ void AppFactory::createAppDirectories(std::string const &appDirectory,
     fs::create_directory(config);
     fs::permissions(config, dirPerms, ec);
     if (ec.value() != 0)
-      LOG(ERROR) << "Cannot set permissions for " << config;
+      SPDLOG_DEBUG("Cannot set permissions for {}", config.c_str());
   }
 
   if (!fs::is_directory(config))
     throw std::runtime_error(
-        fmt::format("{} is not a directory", config.c_str()));
+        std::format("{} is not a directory", config.c_str()));
 
   fs::path appConfigDir = config / appDirectory;
   if (!fs::exists(appConfigDir)) {
     fs::create_directory(appConfigDir);
     fs::permissions(appConfigDir, dirPerms, ec);
     if (ec.value() != 0)
-      LOG(ERROR) << "Cannot set permissions for " << appConfigDir;
+      SPDLOG_DEBUG("Cannot set permissions for {}", appConfigDir.c_str());
   }
 
   if (!fs::is_directory(appConfigDir))
     throw std::runtime_error(
-        fmt::format("{} is not a directory", appConfigDir.c_str()));
+        std::format("{} is not a directory", appConfigDir.c_str()));
 
   if (!fs::exists(cache)) {
     fs::create_directory(cache);
     fs::permissions(cache, dirPerms, ec);
     if (ec.value() != 0)
-      LOG(ERROR) << "Cannot set permissions for " << cache;
+      SPDLOG_DEBUG("Cannot set permissions for {}", cache.c_str());
   }
 
   if (!fs::is_directory(cache))
-    throw std::runtime_error(fmt::format("{} is not a directory", cache.c_str()));
+    throw std::runtime_error(std::format("{} is not a directory", cache.c_str()));
 
   fs::path cacheApp = cache / appDirectory;
   if (!fs::exists(cacheApp)) {
     fs::create_directory(cacheApp);
     fs::permissions(cacheApp, dirPerms, ec);
     if (ec.value() != 0)
-      LOG(ERROR) << "Cannot set permissions for " << cacheApp;
+      SPDLOG_DEBUG("Cannot set permissions for {}", cacheApp.c_str());
   }
 
   if (!fs::is_directory(cacheApp))
     throw std::runtime_error(
-        fmt::format("{} is not a directory", cacheApp.c_str()));
+        std::format("{} is not a directory", cacheApp.c_str()));
 }
