@@ -3,6 +3,7 @@
 
 #pragma once
 
+#include "core/idatasource.h"
 #include "ippdpmhandler.h"
 #include <memory>
 #include <string>
@@ -10,9 +11,6 @@
 #include <utility>
 #include <vector>
 
-template<typename...>
-class IDataSource;
-
 namespace AMD {
 
 class PpDpmHandler : public IPpDpmHandler
