@@ -24,9 +24,11 @@ class CPUFreqProfilePart::Initializer final : public CPUFreq::Exporter
 
   void takeActive(bool active) override;
   void takeCPUFreqScalingGovernor(std::string const &governor) override;
-
   void
   takeCPUFreqScalingGovernors(std::vector<std::string> const &governors) override;
+  void takeCPUFreqEPPHint(std::optional<std::string> const &hint) override;
+  void
+  takeCPUFreqEPPHints(std::optional<std::vector<std::string>> const &hints) override;
 
  private:
   CPUFreqProfilePart &outer_;
@@ -49,6 +51,18 @@ void CPUFreqProfilePart::Initializer::takeCPUFreqScalingGovernors(
   outer_.governors_ = governors;
 }
 
+void CPUFreqProfilePart::Initializer::takeCPUFreqEPPHint(
+    std::optional<std::string> const &hint)
+{
+  outer_.eppHint_ = hint;
+}
+
+void CPUFreqProfilePart::Initializer::takeCPUFreqEPPHints(
+    std::optional<std::vector<std::string>> const &hints)
+{
+  outer_.eppHints_ = hints;
+}
+
 CPUFreqProfilePart::CPUFreqProfilePart() noexcept
 : id_(CPUFreq::ItemID)
 {
@@ -86,16 +100,23 @@ std::string const &CPUFreqProfilePart::provideCPUFreqScalingGovernor() const
   return governor_;
 }
 
+std::optional<std::string> const &CPUFreqProfilePart::provideCPUFreqEPPHint() const
+{
+  return eppHint_;
+}
+
 void CPUFreqProfilePart::importProfilePart(IProfilePart::Importer &i)
 {
-  auto &cpuFreqImporter = dynamic_cast<CPUFreqProfilePart::Importer &>(i);
-  governor(cpuFreqImporter.provideCPUFreqScalingGovernor());
+  auto &importer = dynamic_cast<CPUFreqProfilePart::Importer &>(i);
+  governor(importer.provideCPUFreqScalingGovernor());
+  eppHint(importer.provideCPUFreqEPPHint());
 }
 
 void CPUFreqProfilePart::exportProfilePart(IProfilePart::Exporter &e) const
 {
-  auto &cpuFreqExporter = dynamic_cast<CPUFreqProfilePart::Exporter &>(e);
-  cpuFreqExporter.takeCPUFreqScalingGovernor(governor_);
+  auto &exporter = dynamic_cast<CPUFreqProfilePart::Exporter &>(e);
+  exporter.takeCPUFreqScalingGovernor(governor_);
+  exporter.takeCPUFreqEPPHint(eppHint_);
 }
 
 std::unique_ptr<IProfilePart> CPUFreqProfilePart::cloneProfilePart() const
@@ -103,6 +124,8 @@ std::unique_ptr<IProfilePart> CPUFreqProfilePart::cloneProfilePart() const
   auto clone = std::make_unique<CPUFreqProfilePart>();
   clone->governors_ = governors_;
   clone->governor_ = governor_;
+  clone->eppHint_ = eppHint_;
+  clone->eppHints_ = eppHints_;
 
   return std::move(clone);
 }
@@ -118,5 +141,18 @@ void CPUFreqProfilePart::governor(std::string const &governor)
     governor_ = governor;
 }
 
+void CPUFreqProfilePart::eppHint(std::optional<std::string> const &hint)
+{
+  if (!hint || !eppHints_)
+    return;
+
+  // only import known hints
+  auto iter = std::find_if(
+      eppHints_->cbegin(), eppHints_->cend(),
+      [&](auto const &availableHint) { return *hint == availableHint; });
+  if (iter != eppHints_->cend())
+    eppHint_ = hint;
+}
+
 bool const CPUFreqProfilePart::registered_ = ProfilePartProvider::registerProvider(
     CPUFreq::ItemID, []() { return std::make_unique<CPUFreqProfilePart>(); });
