@@ -4,15 +4,13 @@
 #pragma once
 
 #include "../igpuinfo.h"
+#include "core/idatasource.h"
 #include <filesystem>
 #include <memory>
 #include <string>
 #include <string_view>
 #include <vector>
 
-template<typename...>
-class IDataSource;
-
 namespace AMD {
 
 /// AMD power management overdrive GPU info
@@ -30,11 +28,11 @@ class GPUInfoPMOverdrive final : public IGPUInfo::IProvider
 
   std::vector<std::pair<std::string, std::string>>
   provideInfo(Vendor vendor, int gpuIndex, IGPUInfo::Path const &path,
-              IHWIDTranslator const &hwIDTranslator) override;
+              IHWIDTranslator const &hwIDTranslator) const override;
 
   std::vector<std::string>
   provideCapabilities(Vendor vendor, int gpuIndex,
-                      IGPUInfo::Path const &path) override;
+                      IGPUInfo::Path const &path) const override;
 
  private:
   std::unique_ptr<IDataSource<std::vector<std::string>,
