@@ -4,15 +4,13 @@
 #pragma once
 
 #include "../igpuinfo.h"
+#include "core/idatasource.h"
 #include <cstddef>
 #include <memory>
 #include <string>
 #include <string_view>
 #include <vector>
 
-template<typename...>
-class IDataSource;
-
 class GPUInfoOpenGL final : public IGPUInfo::IProvider
 {
  public:
@@ -27,10 +25,11 @@ class GPUInfoOpenGL final : public IGPUInfo::IProvider
 
   std::vector<std::pair<std::string, std::string>>
   provideInfo(Vendor vendor, int gpuIndex, IGPUInfo::Path const &path,
-              IHWIDTranslator const &hwIDTranslator) override;
+              IHWIDTranslator const &hwIDTranslator) const override;
 
   std::vector<std::string>
-  provideCapabilities(Vendor vendor, int, IGPUInfo::Path const &path) override;
+  provideCapabilities(Vendor vendor, int,
+                      IGPUInfo::Path const &path) const override;
 
  private:
   std::string findItem(std::string const &src, std::string_view itemStr,
