@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 #include <catch2/trompeloeil.hpp>
 
 #include "common/commandqueuestub.h"
@@ -10,9 +10,7 @@
 
 extern template struct trompeloeil::reporter<trompeloeil::specialized>;
 
-namespace Tests {
-namespace AMD {
-namespace FanCurve {
+namespace Tests::AMD::FanCurve {
 
 class FanCurveTestAdapter : public ::AMD::FanCurve
 {
@@ -637,6 +635,5 @@ TEST_CASE("AMD FanCurve tests", "[GPU][AMD][Fan][FanCurve]")
     }
   }
 }
-} // namespace FanCurve
-} // namespace AMD
-} // namespace Tests
+
+} // namespace Tests::AMD::FanCurve
