@@ -1,12 +1,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2021 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "core/components/controls/cpu/cpufreqmode.h"
 
-namespace Tests {
-namespace CPUFreqMode {
+namespace Tests::CPUFreqMode {
 
 TEST_CASE("AMD CPUFreqMode tests", "[CPU][CPUFreqMode]")
 {
@@ -24,5 +23,5 @@ TEST_CASE("AMD CPUFreqMode tests", "[CPU][CPUFreqMode]")
     REQUIRE(ts.active());
   }
 }
-} // namespace CPUFreqMode
-} // namespace Tests
+
+} // namespace Tests::CPUFreqMode
