@@ -1,14 +1,13 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "common/hwidtranslatorstub.h"
 #include "common/stringpathdatasourcestub.h"
 #include "core/info/common/gpuinforevision.h"
 
-namespace Tests {
-namespace GPUInfoRevision {
+namespace Tests::GPUInfoRevision {
 
 TEST_CASE("GPUInfoRevision tests", "[Info][GPUInfo][GPUInfoRevision]")
 {
@@ -27,8 +26,8 @@ TEST_CASE("GPUInfoRevision tests", "[Info][GPUInfo][GPUInfoRevision]")
 
     auto revision = std::make_pair(std::string(IGPUInfo::Keys::revision),
                                    std::string("123"));
-    REQUIRE_THAT(output, Catch::VectorContains(revision));
+    REQUIRE_THAT(output, Catch::Matchers::VectorContains(revision));
   }
 }
-} // namespace GPUInfoRevision
-} // namespace Tests
+
+} // namespace Tests::GPUInfoRevision
